@@ -36,6 +36,18 @@ class BaseDistribution(nn.Module):
         """
         raise NotImplementedError
 
+    def sample(self, num_samples=1, **kwargs):
+        """Samples from base distribution
+
+        Args:
+          num_samples: Number of samples to draw from the distriubtion
+
+        Returns:
+          Samples drawn from the distribution
+        """
+        z, _ = self.forward(num_samples, **kwargs)
+        return z
+
 
 class DiagGaussian(BaseDistribution):
     """
@@ -51,6 +63,8 @@ class DiagGaussian(BaseDistribution):
         super().__init__()
         if isinstance(shape, int):
             shape = (shape,)
+        if isinstance(shape, list):
+            shape = tuple(shape)
         self.shape = shape
         self.n_dim = len(shape)
         self.d = np.prod(shape)
@@ -104,6 +118,8 @@ class UniformGaussian(BaseDistribution):
         """
         super().__init__()
         self.ndim = ndim
+        if isinstance(ind, int):
+            ind = [ind]
 
         # Set up indices and permutations
         self.ndim = ndim
@@ -176,6 +192,8 @@ class ClassCondDiagGaussian(BaseDistribution):
         super().__init__()
         if isinstance(shape, int):
             shape = (shape,)
+        if isinstance(shape, list):
+            shape = tuple(shape)
         self.shape = shape
         self.n_dim = len(shape)
         self.perm = [self.n_dim] + list(range(self.n_dim))
@@ -251,6 +269,8 @@ class GlowBase(BaseDistribution):
         # Save shape and related statistics
         if isinstance(shape, int):
             shape = (shape,)
+        if isinstance(shape, list):
+            shape = tuple(shape)
         self.shape = shape
         self.n_dim = len(shape)
         self.num_pix = np.prod(shape[1:])
@@ -373,6 +393,10 @@ class AffineGaussian(BaseDistribution):
           num_classes: Number of classes if the base is class conditional, None otherwise
         """
         super().__init__()
+        if isinstance(shape, int):
+            shape = (shape,)
+        if isinstance(shape, list):
+            shape = tuple(shape)
         self.shape = shape
         self.n_dim = len(shape)
         self.d = np.prod(shape)
@@ -421,6 +445,9 @@ class AffineGaussian(BaseDistribution):
         else:
             z, log_det = self.transform(z)
         log_p -= log_det
+        print(y)
+        print(eps)
+        print(z)
         return z, log_p
 
     def log_prob(self, z, y=None):
@@ -450,6 +477,8 @@ class AffineGaussian(BaseDistribution):
             - 0.5 * self.d * np.log(2 * np.pi)
             - 0.5 * torch.sum(torch.pow(z, 2), dim=self.sum_dim)
         )
+        print(y)
+        print(z)
         return log_p
 
 
