@@ -46,24 +46,26 @@ class NNDiagGaussianDecoder(BaseDecoder):
         self.net = net
 
     def forward(self, z):
-        z_size = z.size()
-        mean_std = self.net(z.view(-1, *z_size[2:])).view(z_size)
-        n_hidden = mean_std.size()[2] // 2
-        mean = mean_std[:, :, :n_hidden, ...]
-        std = torch.exp(0.5 * mean_std[:, :, n_hidden : (2 * n_hidden), ...])
+        mean_std = self.net(z)
+        n_hidden = mean_std.size()[1] // 2
+        mean = mean_std[:, :n_hidden, ...]
+        std = torch.exp(0.5 * mean_std[:, n_hidden:, ...])
         return mean, std
 
     def log_prob(self, x, z):
-        mean_std = self.net(z.view(-1, *z.size()[2:])).view(
-            *z.size()[:2], x.size(1) * 2, *x.size()[3:]
-        )
-        n_hidden = mean_std.size()[2] // 2
-        mean = mean_std[:, :, :n_hidden, ...]
-        var = torch.exp(mean_std[:, :, n_hidden : (2 * n_hidden), ...])
-        log_p = -0.5 * torch.prod(torch.tensor(z.size()[2:])) * np.log(
+        mean_std = self.net(z)
+        n_hidden = mean_std.size()[1] // 2
+        mean = mean_std[:, :n_hidden, ...]
+        var = torch.exp(mean_std[:, n_hidden:, ...])
+        if len(z) > len(x):
+            x = x.unsqueeze(1)
+            x = x.repeat(1, z.size()[0] // x.size()[0], *((x.dim() - 2) * [1])).view(
+                -1, *x.size()[2:]
+            )
+        log_p = -0.5 * torch.prod(torch.tensor(z.size()[1:])) * np.log(
             2 * np.pi
         ) - 0.5 * torch.sum(
-            torch.log(var) + (x.unsqueeze(1) - mean) ** 2 / var, list(range(2, z.dim()))
+            torch.log(var) + (x - mean) ** 2 / var, list(range(1, z.dim()))
         )
         return log_p
 
@@ -88,10 +90,11 @@ class NNBernoulliDecoder(BaseDecoder):
 
     def log_prob(self, x, z):
         score = self.net(z)
-        x = x.unsqueeze(1)
-        x = x.repeat(1, z.size()[0] // x.size()[0], *((x.dim() - 2) * [1])).view(
-            -1, *x.size()[2:]
-        )
+        if len(z) > len(x):
+            x = x.unsqueeze(1)
+            x = x.repeat(1, z.size()[0] // x.size()[0], *((x.dim() - 2) * [1])).view(
+                -1, *x.size()[2:]
+            )
         log_sig = lambda a: -torch.relu(-a) - torch.log(1 + torch.exp(-torch.abs(a)))
         log_p = torch.sum(
             x * log_sig(score) + (1 - x) * log_sig(-score), list(range(1, x.dim()))
