@@ -108,8 +108,13 @@ class TwoModes(PriorDistribution):
     def __init__(self, loc, scale):
         """Distribution 2d with two modes
 
-        Distribution 2d with two modes at:
+        Distribution 2d with two modes at
         ```z[0] = -loc```  and ```z[0] = loc```
+        following the density
+        ```
+        log(p) = 1/2 * ((norm(z) - loc) / (2 * scale)) ** 2
+                - log(exp(-1/2 * ((z[0] - loc) / (3 * scale)) ** 2) + exp(-1/2 * ((z[0] + loc) / (3 * scale)) ** 2))
+        ```
 
         Args:
           loc: distance of modes from the origin
@@ -147,10 +152,16 @@ class TwoModes(PriorDistribution):
 class Sinusoidal(PriorDistribution):
     def __init__(self, scale, period):
         """Distribution 2d with sinusoidal density
+        given by
+
+        ```
+        w_1(z) = sin(2*pi / period * z[0])
+        log(p) = - 1/2 * ((z[1] - w_1(z)) / (2 * scale)) ** 2
+        ```
 
         Args:
-          loc: distance of modes from the origin
-          scale: scale of modes
+          scale: scale of the distribution, see formula
+          period: period of the sinosoidal
         """
         self.scale = scale
         self.period = period
@@ -186,6 +197,13 @@ class Sinusoidal(PriorDistribution):
 class Sinusoidal_gap(PriorDistribution):
     def __init__(self, scale, period):
         """Distribution 2d with sinusoidal density with gap
+        given by
+
+        ```
+        w_1(z) = sin(2*pi / period * z[0])
+        w_2(z) = 3 * exp(-0.5 * ((z[0] - 1) / 0.6) ** 2)
+        log(p) = -log(exp(-0.5 * ((z[1] - w_1(z)) / 0.35) ** 2) + exp(-0.5 * ((z[1] - w_1(z) + w_2(z)) / 0.35) ** 2))
+        ```
 
         Args:
           loc: distance of modes from the origin
@@ -230,6 +248,13 @@ class Sinusoidal_gap(PriorDistribution):
 class Sinusoidal_split(PriorDistribution):
     def __init__(self, scale, period):
         """Distribution 2d with sinusoidal density with split
+        given by
+
+        ```
+        w_1(z) = sin(2*pi / period * z[0])
+        w_3(z) = 3 * sigmoid((z[0] - 1) / 0.3)
+        log(p) = -log(exp(-0.5 * ((z[1] - w_1(z)) / 0.4) ** 2) + exp(-0.5 * ((z[1] - w_1(z) + w_3(z)) / 0.35) ** 2))
+        ```
 
         Args:
           loc: distance of modes from the origin
@@ -276,8 +301,7 @@ class Smiley(PriorDistribution):
         """Distribution 2d of a smiley :)
 
         Args:
-          loc: distance of modes from the origin
-          scale: scale of modes
+          scale: scale of the smiley
         """
         self.scale = scale
         self.loc = 2.0
